{ config, lib, pkgs, ... }:

with lib;

let
  tickerSrc =
    builtins.fetchGit { url = "https://gitea.c3d2.de/astro/ticker.git"; };
in {
  boot.isContainer = true;
  #boot.loader.initScript.enable = true;
  networking.hostName = mkDefault "ticker";
  networking.useDHCP = false;
  networking.firewall.allowedTCPPorts = [ 8400 ];
  nix.useSandbox = false;
  environment.systemPackages = with pkgs; [ vim git ];
  imports = [ "${tickerSrc}/nixos-module.nix" ];
  services.ticker.updateInterval = "hourly";
  services.ticker.config.calendars = {
    c3d2 = {
      url = "https://c3d2.de/ical.ics";
      color = "#BFBF3F";
    };
    dresden-science = {
      url = "https://www.dresden-science-calendar.de/calendar/de/iCalSync.ics";
      color = "#00007F";
    };
    gruenes-brett = {
      url = "https://gruenesbrett.net/events.ics";
      color = "#00BF00";
    };
    stura-htw = {
      url = "http://www.stura.htw-dresden.de/events/aggregator/ics_view";
      color = "#BFA73F";
    };
    malobeo = {
      url = "https://malobeo.org/events/list/?ical=1&tribe_display=all";
      color = "#FF3F3F";
    };
    hicknhack = {
      url =
        "https://www.google.com/calendar/ical/grhnk1uaotql6gv2dkf9ldmqjc%40group.calendar.google.com/public/basic.ics";
      color = "#A700A7";
    };
    palaissommer = {
      url = "https://palaissommer.de/programm/?event=all";
      color = "#BF003F";
    };
    kreta = {
      url = "https://www.kreta-dresden.org/kreta.ics";
      color = "#BF3F7F";
    };
    zentralwerk = {
      url = "https://ics.teamup.com/feed/ksayh65fgotv2prcas/0.ics";
      color = "#FF3F3F";
    };
    and = {
      url = "https://and.notraces.net/events/?ical=1";
      color = "#FF7F00";
    };
    rosenwerk-home = {
      url =
        "https://www.google.com/calendar/ical/bj85d742g31mgkblbaiusmk3s8%40group.calendar.google.com/public/basic.ics";
      color = "#BF003F";
    };
    rosenwerk-extern = {
      url =
        "https://www.google.com/calendar/ical/ogo94kraeq5ckmu3jsr0uus2mo%40group.calendar.google.com/private-8d048bfa99cca84705ffa675aacfe22a/basic.ics";
      color = "#BF002F";
    };
    rosenwerk-kultur = {
      url =
        "https://www.google.com/calendar/ical/93enn926ddhgr79hnqp83ipj3g%40group.calendar.google.com/public/basic.ics";
      color = "#BF001F";
    };
    haengemathe = {
      url = "https://club-haengemathe.de/termine.ics";
      color = "#FF7F3F";
    };
    bitsundbaeumedresden = {
      url = "https://dresden.bits-und-baeume.org/termine.ics";
      color = "#3FBF3F";
    };
    exma-stuta = {
      url = "https://www.exmatrikulationsamt.de/ics/v1/stuta.ics";
      color = "#7F7FFF";
    };
    exma-nawa = {
      url = "https://www.exmatrikulationsamt.de/ics/v1/nawa.ics";
      color = "#3F3FBF";
    };
  };
}
